Nesse curso é ensinado como contribuir com projetos de código aberto

Link do curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/FlavioFMBorges/libpythonpro.svg?branch=main)](https://travis-ci.org/FlavioFMBorges/libpythonpro)

Suportada versão 3 de Python

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```
Para conferir qualidade do código:
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip 
